package com.zhentao.controller;

import com.zhentao.pojo.TProduct;
import com.zhentao.service.TProductService;
import com.zhentao.util.SignUtil;
import com.zhentao.vo.ResultVo;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;

@RestController
@RequestMapping("/api/product")
public class ProductController {

    private static final String APP_SECRET = "123";
    private static final String SUCCESS_CODE = "200";
    private static final String FAILURE_CODE = "1002";

    private final TProductService productService;

    public ProductController(TProductService productService) {
        this.productService = productService;
    }

    @GetMapping("/info")
    public ResultVo<String> getProductInfo(@RequestParam("goodsId") Long goodsId,
                                           HttpServletRequest request) {
        // 验签逻辑
        String reqId = request.getHeader("reqId");
        String reqTimeStr = request.getHeader("reqTime");
        String appId = request.getHeader("appId");
        String sign = request.getHeader("sign");

        // 参数校验
        if (goodsId == null || reqId == null || reqTimeStr == null || appId == null || sign == null) {
            return new ResultVo<>(FAILURE_CODE, "参数缺失", null);
        }

        long reqTime;
        try {
            reqTime = Long.parseLong(reqTimeStr);
        } catch (NumberFormatException e) {
            return new ResultVo<>(FAILURE_CODE, "时间戳格式错误", null);
        }

        // 验证时间戳有效性
        long currentTime = System.currentTimeMillis();
        if (Math.abs(currentTime - reqTime) > 30*1000) {
            return new ResultVo<>(FAILURE_CODE, "请求已过期", null);
        }

        // 构建待签名参数
        Map<String, String> params = new HashMap<>();
        params.put("goodsId", goodsId.toString());
        params.put("reqId", reqId);
        params.put("reqTime", reqTimeStr);
        params.put("appId", appId);

        // 验签
        if (!SignUtil.verifySign(params, sign, APP_SECRET)) {
            return new ResultVo<>(FAILURE_CODE, "签名验证失败", null);
        }

        // 获取商品信息
        TProduct product = productService.getProductById(goodsId);
        if (product == null) {
            return new ResultVo<>(FAILURE_CODE, "商品不存在", null);
        }

        return new ResultVo<>(SUCCESS_CODE, "成功", product.getName());
    }
}
